@@ -189,7 +189,7 @@ class Receipt(Document):
         total_vat = 0
         reconstructed_total = 0
         for tax in self.taxes:
-            if tax.value is None or tax.rate is None:
+            if tax.value is None or tax.rate is None or tax.rate == 0:
                 return False
             total_vat += tax.value
             reconstructed_total += tax.value + 100 * tax.value / tax.rate
